@@ -1,33 +1,23 @@
-/* This file is part of the KDE project
-   Copyright (C) 1999 David Faure <faure@kde.org>
-                 2001, 2002, 2004-2006 Michael Brade <brade@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 1999 David Faure <faure@kde.org>
+    SPDX-FileCopyrightText: 2001, 2002, 2004-2006 Michael Brade <brade@kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #ifndef KCOREDIRLISTER_H
 #define KCOREDIRLISTER_H
 
-#include "kfileitem.h"
 #include "kdirnotify.h" // TODO SIC: remove
+#include "kfileitem.h"
 
 #include <QString>
 #include <QStringList>
 #include <QUrl>
 
+#include <memory>
+
 class KJob;
 namespace KIO
 {
@@ -35,6 +25,8 @@ class Job;
 class ListJob;
 }
 
+class KCoreDirListerPrivate;
+
 /**
  * @class KCoreDirLister kcoredirlister.h <KCoreDirLister>
  *
@@ -73,20 +65,26 @@ class KIOCORE_EXPORT KCoreDirLister : public QObject
     Q_PROPERTY(QStringList mimeFilter READ mimeFilters WRITE setMimeFilter RESET clearMimeFilter)
 
 public:
+    /**
+     * @see OpenUrlFlags
+     */
     enum OpenUrlFlag {
-        NoFlags = 0x0,   ///< No additional flags specified.
+        NoFlags = 0x0, ///< No additional flags specified.
 
-        Keep = 0x1,      ///< Previous directories aren't forgotten
+        Keep = 0x1, ///< Previous directories aren't forgotten
         ///< (they are still watched by kdirwatch and their items
         ///< are kept for this KCoreDirLister). This is useful for e.g.
         ///< a treeview.
 
-        Reload = 0x2     ///< Indicates whether to use the cache or to reread
-                 ///< the directory from the disk.
-                 ///< Use only when opening a dir not yet listed by this lister
-                 ///< without using the cache. Otherwise use updateDirectory.
+        Reload = 0x2, ///< Indicates whether to use the cache or to reread
+                      ///< the directory from the disk.
+                      ///< Use only when opening a dir not yet listed by this lister
+                      ///< without using the cache. Otherwise use updateDirectory.
     };
 
+    /**
+     * Stores a combination of #OpenUrlFlag values.
+     */
     Q_DECLARE_FLAGS(OpenUrlFlags, OpenUrlFlag)
 
     /**
@@ -102,27 +100,30 @@ public:
     /**
      * Run the directory lister on the given url.
      *
-     * This method causes KCoreDirLister to emit _all_ the items of @p _url, in any case.
-     * Depending on _flags, either clear() or clear(const QUrl &) will be
-     * emitted first.
+     * This method causes KCoreDirLister to emit @em all the items of @p dirUrl, in any case.
+     * Depending on @p flags, either clear() or clearDir(const QUrl &) will be emitted first.
      *
-     * The newItems() signal may be emitted more than once to supply you
-     * with KFileItems, up until the signal completed() is emitted
-     * (and isFinished() returns true).
+     * The newItems() signal may be emitted more than once to supply you with KFileItems, up
+     * until the signal completed() is emitted (and isFinished() returns @c true).
      *
-     * @param _url     the directory URL.
-     * @param _flags   whether to keep previous directories, and whether to reload, see OpenUrlFlags
-     * @return true    if successful,
-     *         false   otherwise (e.g. invalid @p _url)
+     * @param dirUrl the directory URL.
+     * @param flags whether to keep previous directories, and whether to reload, see OpenUrlFlags
+     * @return @c true if successful, @c false otherwise (e.g. if @p dirUrl is invalid)
+     *
+     * @note clearDir(const QUrl &) is emitted since 5.79; before that it was clear(const QUrl &)
+     * which has been deprecated.
      */
-    virtual bool openUrl(const QUrl &_url, OpenUrlFlags _flags = NoFlags);
+    virtual bool openUrl(const QUrl &dirUrl, OpenUrlFlags flags = NoFlags);
 
     /**
      * Stop listing all directories currently being listed.
      *
      * Emits canceled() if there was at least one job running.
-     * Emits canceled( const QUrl& ) for each stopped job if
-     * there are at least two directories being watched by KCoreDirLister.
+     * Emits listingDirCanceled(const QUrl &) for each stopped job if there is more than one
+     * directory being watched by this KCoreDirLister.
+     *
+     * @note listingDirCanceled(const QUrl &) is emitted since 5.79; before that it was
+     * canceled(const QUrl &) which has been deprecated.
      */
     virtual void stop();
 
@@ -130,25 +131,30 @@ public:
      * Stop listing the given directory.
      *
      * Emits canceled() if the killed job was the last running one.
-     * Emits canceled( const QUrl& ) for the killed job if
-     * there are at least two directories being watched by KCoreDirLister.
-     * No signal is emitted if there was no job running for @p _url.
-     * @param _url the directory URL
+     * Emits listingDirCanceled(const QUrl &) for the killed job if there is more than one
+     * directory being watched by this KCoreDirLister.
+     *
+     * No signal is emitted if there was no job running for @p dirUrl.
+     *
+     * @param dirUrl the directory URL
+     *
+     * @note listingDirCanceled(const QUrl &) is emitted since 5.79; before that it was
+     * canceled(const QUrl &) which has been deprecated.
      */
-    virtual void stop(const QUrl &_url);
+    virtual void stop(const QUrl &dirUrl);
 
     /**
-     * @return true if the "delayed mimetypes" feature was enabled
+     * @return @c true if the "delayed MIME types" feature was enabled
      * @see setDelayedMimeTypes
      */
     bool delayedMimeTypes() const;
 
     /**
-     * Delayed mimetypes feature:
-     * If enabled, mime types will be fetched on demand, which leads to a
+     * Delayed MIME types feature:
+     * If enabled, MIME types will be fetched on demand, which leads to a
      * faster initial directory listing, where icons get progressively replaced
      * with the correct one while KMimeTypeResolver is going through the items
-     * with unknown or imprecise mimetype (e.g. files with no extension or an
+     * with unknown or imprecise MIME type (e.g. files with no extension or an
      * unknown extension).
      */
     void setDelayedMimeTypes(bool delayedMimeTypes);
@@ -156,59 +162,68 @@ public:
     /**
      * Checks whether KDirWatch will automatically update directories. This is
      * enabled by default.
-     * @return true if KDirWatch is used to automatically update directories.
+     *
+     * @return @c true if KDirWatch is used to automatically update directories
      */
     bool autoUpdate() const;
 
     /**
-     * Enable/disable automatic directory updating, when a directory changes
-     * (using KDirWatch).
-     * @param enable true to enable, false to disable
+     * Toggle automatic directory updating, when a directory changes (using KDirWatch).
+     *
+     * @param enable set to @c true to enable or @c false to disable
      */
     virtual void setAutoUpdate(bool enable);
 
     /**
-     * Checks whether hidden files (files beginning with a dot) will be
-     * shown.
-     * By default this option is disabled (hidden files will be not shown).
-     * @return true if dot files are shown, false otherwise
+     * Checks whether hidden files (files whose name start with '.') will be shown.
+     * By default this option is disabled (hidden files are not shown).
+     *
+     * @return @c true if dot files are shown, @c false otherwise
+     *
      * @see setShowingDotFiles()
      */
     bool showingDotFiles() const;
 
     /**
-     * Changes the "is viewing dot files" setting.
+     * Toggles whether hidden files (files whose name start with '.') are shown, by default
+     * hidden files are not shown.
+     *
      * You need to call emitChanges() afterwards.
-     * By default this option is disabled (hidden files will not be shown).
-     * @param _showDotFiles true to enable showing hidden files, false to
-     *        disable
+     *
+     * @param showDotFiles set to @c true/false to show/hide hidden files respectively
+     *
      * @see showingDotFiles()
      */
-    virtual void setShowingDotFiles(bool _showDotFiles);
+    virtual void setShowingDotFiles(bool showDotFiles);
 
     /**
-     * Checks whether the KCoreDirLister only lists directories or all
-     * files.
-     * By default this option is disabled (all files will be shown).
-     * @return true if setDirOnlyMode(true) was called
+     * Checks whether this KCoreDirLister only lists directories or all items (directories and
+     * files), by default all items are listed.
+     *
+     * @return @c true if only directories are listed, @c false otherwise
+     *
+     * @see setDirOnlyMode(bool)
      */
     bool dirOnlyMode() const;
 
     /**
-     * Call this to list only directories.
+     * Call this to list only directories (by default all items (directories and files)
+     * are listed).
+     *
      * You need to call emitChanges() afterwards.
-     * By default this option is disabled (all files will be shown).
-     * @param dirsOnly true to list only directories
+     *
+     * @param dirsOnly set to @c true to list only directories
      */
     virtual void setDirOnlyMode(bool dirsOnly);
 
     /**
      * Returns the top level URL that is listed by this KCoreDirLister.
+     *
      * It might be different from the one given with openUrl() if there was a
      * redirection. If you called openUrl() with OpenUrlFlag::Keep this is the
      * first url opened (e.g. in a treeview this is the root).
      *
-     * @return the url used by this instance to list the files.
+     * @return the url used by this instance to list the files
      */
     QUrl url() const;
 
@@ -218,7 +233,7 @@ public:
      * treeview, for example. (Note that the base url is included in the list
      * as well, of course.)
      *
-     * @return the list of all listed URLs
+     * @return a list of all listed URLs
      */
     QList<QUrl> directories() const;
 
@@ -229,21 +244,21 @@ public:
     virtual void emitChanges();
 
     /**
-     * Update the directory @p _dir. This method causes KCoreDirLister to _only_ emit
-     * the items of @p _dir that actually changed compared to the current state in the
-     * cache and updates the cache.
+     * Update the directory @p dirUrl. This method causes KCoreDirLister to @em only emit
+     * the items of @p dirUrl that actually changed compared to the current state in the
+     * cache, and updates the cache.
      *
-     * The current implementation calls updateDirectory automatically for
-     * local files, using KDirWatch (if autoUpdate() is true), but it might be
-     * useful to force an update manually.
+     * The current implementation calls updateDirectory automatically for local files, using
+     * KDirWatch (if autoUpdate() is @c true), but it might be useful to force an update manually.
      *
-     * @param _dir the directory URL
+     * @param dirUrl the directory URL
      */
-    virtual void updateDirectory(const QUrl &_dir);
+    virtual void updateDirectory(const QUrl &dirUrl);
 
     /**
-     * Returns true if no io operation is currently in progress.
-     * @return true if finished, false otherwise
+     * Returns @c true if no I/O operation is currently in progress.
+     *
+     * @return @c true if finished, @c false otherwise
      */
     bool isFinished() const;
 
@@ -257,10 +272,10 @@ public:
 
     /**
      * Find an item by its URL.
-     * @param _url the item URL
+     * @param url the item URL
      * @return the KFileItem
      */
-    virtual KFileItem findByUrl(const QUrl &_url) const;
+    virtual KFileItem findByUrl(const QUrl &url) const;
 
     /**
      * Find an item by its name.
@@ -290,14 +305,14 @@ public:
     QString nameFilter() const;
 
     /**
-     * Set mime-based filter to only list items matching the given mimetypes.
+     * Set MIME type based filter to only list items matching the given MIME types.
      *
      * NOTE: setting the filter does not automatically reload directory.
      * Also calling this function will not affect any named filter already set.
      *
      * You need to call emitChanges() afterwards.
      *
-     * @param mimeList a list of mime-types.
+     * @param mimeList a list of MIME types
      *
      * @see clearMimeFilter
      * @see matchesMimeFilter
@@ -308,12 +323,12 @@ public:
      * Filtering should be done with KFileFilter. This will be implemented in a later
      * revision of KCoreDirLister. This method may be removed then.
      *
-     * Set mime-based exclude filter to only list items not matching the given mimetypes
+     * Set MIME type based exclude filter to only list items not matching the given MIME types
      *
      * NOTE: setting the filter does not automatically reload directory.
      * Also calling this function will not affect any named filter already set.
      *
-     * @param mimeList a list of mime-types.
+     * @param mimeList a list of MIME types
      * @see clearMimeFilter
      * @see matchesMimeFilter
      * @internal
@@ -321,7 +336,7 @@ public:
     void setMimeExcludeFilter(const QStringList &mimeList);
 
     /**
-     * Clears the mime based filter.
+     * Clears the MIME type based filter.
      *
      * You need to call emitChanges() afterwards.
      *
@@ -330,27 +345,30 @@ public:
     virtual void clearMimeFilter();
 
     /**
-     * Returns the list of mime based filters, as set via setMimeFilter().
-     * @return the list of mime based filters. Empty, when no mime filter is set.
+     * Returns the list of MIME type based filters, as set via setMimeFilter().
+     * @return the list of MIME type based filters. Empty, when no MIME type filter is set.
      */
     QStringList mimeFilters() const;
 
     /**
      * Checks whether @p name matches a filter in the list of name filters.
-     * @return true if @p name matches a filter in the list,
-     * otherwise false.
-     * @see setNameFilter
+     *
+     * @return @c true if @p name matches a filter in the list, otherwise @c false.
+     *
+     * @see setNameFilter()
      */
     bool matchesFilter(const QString &name) const;
 
     /**
-     * Checks whether @p mime matches a filter in the list of mime types
-     * @param mime the mimetype to find in the filter list.
-     * @return true if @p name matches a filter in the list,
-     * otherwise false.
+     * Checks whether @p mimeType matches a filter in the list of MIME types.
+     *
+     * @param mimeType the MIME type to find in the filter list
+     *
+     * @return @c true if @p mimeType matches a filter in the list, otherwise @c false
+     *
      * @see setMimeFilter.
      */
-    bool matchesMimeFilter(const QString &mime) const;
+    bool matchesMimeFilter(const QString &mimeType) const;
 
     /**
      * Used by items() and itemsForDir() to specify whether you want
@@ -358,123 +376,178 @@ public:
      */
     enum WhichItems {
         AllItems = 0,
-        FilteredItems = 1
+        FilteredItems = 1,
     };
 
     /**
      * Returns the items listed for the current url().
-     * This method will NOT start listing a directory, you should only call
-     * this when receiving the finished() signal.
      *
-     * The items in the KFileItemList are copies of the items used
-     * by KCoreDirLister.
+     * This method will @em not start listing a directory, you should only call
+     * this in a slot connected to the finished() signal.
+     *
+     * The items in the KFileItemList are copies of the items used by KCoreDirLister.
      *
      * @param which specifies whether the returned list will contain all entries
      *              or only the ones that passed the nameFilter(), mimeFilter(),
      *              etc. Note that the latter causes iteration over all the
      *              items, filtering them. If this is too slow for you, use the
-     *              newItems() signal, sending out filtered items in chunks.
-     * @return the items listed for the current url().
+     *              newItems() signal, sending out filtered items in chunks
+     * @return the items listed for the current url()
      */
     KFileItemList items(WhichItems which = FilteredItems) const;
 
     /**
-     * Returns the items listed for the given @p dir.
-     * This method will NOT start listing @p dir, you should only call
-     * this when receiving the finished() signal.
+     * Returns the items listed for the given @p dirUrl.
+     * This method will @em not start listing @p dirUrl, you should only call
+     * this in a slot connected to the finished() signal.
      *
-     * The items in the KFileItemList are copies of the items used
-     * by KCoreDirLister.
+     * The items in the KFileItemList are copies of the items used by KCoreDirLister.
      *
-     * @param dir specifies the url for which the items should be returned. This
+     * @param dirUrl specifies the url for which the items should be returned. This
      *            is only useful if you use KCoreDirLister with multiple URLs
-     *            i.e. using bool OpenUrlFlag::Keep in openUrl().
+     *            i.e. using bool OpenUrlFlag::Keep in openUrl()
      * @param which specifies whether the returned list will contain all entries
      *              or only the ones that passed the nameFilter, mimeFilter, etc.
      *              Note that the latter causes iteration over all the items,
      *              filtering them. If this is too slow for you, use the
-     * newItems() signal, sending out filtered items in chunks.
-     * @return the items listed for @p dir.
+     * newItems() signal, sending out filtered items in chunks
+     *
+     * @return the items listed for @p dirUrl
      */
-    KFileItemList itemsForDir(const QUrl &dir,
-                              WhichItems which = FilteredItems) const;
+    KFileItemList itemsForDir(const QUrl &dirUrl, WhichItems which = FilteredItems) const;
 
     /**
-     * Return the KFileItem for the given URL, if we listed it recently
-     * and it's still in the cache - which is always the case if a directory
-     * view is currently showing this item. If not, then it might be in the
-     * cache, or it might not, in which case you get a null KFileItem.
-     * If you really need a KFileItem for this URL in all cases, then use
-     * KIO::stat() instead.
+     * Return the KFileItem for the given URL, if it was listed recently and it's
+     * still in the cache, which is always the case if a directory view is currently
+     * showing this item. If not, then it might be in the cache; if not in the cache a
+     * a null KFileItem will be returned.
+     *
+     * If you really need a KFileItem for this URL in all cases, then use KIO::stat() instead.
      *
      * @since 4.2
      */
     static KFileItem cachedItemForUrl(const QUrl &url);
 
 Q_SIGNALS:
-
     /**
-     * Tell the view that we started to list @p _url. NOTE: this does _not_ imply that there
-     * is really a job running! I.e. KCoreDirLister::jobs() may return an empty list. In this case
-     * the items are taken from the cache.
+     * Tell the view that this KCoreDirLister has started to list @p dirUrl. Note that this
+     * does @em not imply that there is really a job running! I.e. KCoreDirLister::jobs()
+     * may return an empty list, in which case the items are taken from the cache.
      *
-     * The view knows that openUrl should start it, so it might seem useless,
-     * but the view also needs to know when an automatic update happens.
-     * @param _url the URL to list
+     * The view knows that openUrl should start it, so this might seem useless, but the view
+     * also needs to know when an automatic update happens.
+     * @param dirUrl the URL to list
      */
-    void started(const QUrl &_url);
+    void started(const QUrl &dirUrl);
 
     /**
      * Tell the view that listing is finished. There are no jobs running anymore.
      */
-    void completed();
+    void completed(); // clazy:exclude=overloaded-signal
+
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 79)
+    /**
+     * Tell the view that the listing of the directory @p dirUrl is finished.
+     * There might be other running jobs left.
+     *
+     * @param dirUrl the directory URL
+     *
+     * @deprecated since 5.79, use KCoreDirLister::listingDirCompleted(const QUrl &)
+     */
+    KIOCORE_DEPRECATED_VERSION(5, 79, "Use KCoreDirLister::listingDirCompleted(const QUrl &)")
+    void completed(const QUrl &dirUrl); // clazy:exclude=overloaded-signal
+#endif
 
     /**
-     * Tell the view that the listing of the directory @p _url is finished.
+     * Tell the view that the listing of the directory @p dirUrl is finished.
      * There might be other running jobs left.
-     * @param _url the directory URL
+     *
+     * @param dirUrl the directory URL
+     *
+     * @since 5.79
      */
-    void completed(const QUrl &_url);
+    void listingDirCompleted(const QUrl &dirUrl);
 
     /**
      * Tell the view that the user canceled the listing. No running jobs are left.
      */
-    void canceled();
+    void canceled(); // clazy:exclude=overloaded-signal
+
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 79)
+    /**
+     * Tell the view that the listing of the directory @p dirUrl was canceled.
+     * There might be other running jobs left.
+     *
+     * @param dirUrl the directory URL
+     *
+     * @deprecated since 5.79, use KCoreDirLister::listingDirCanceled(const QUrl &)
+     */
+    KIOCORE_DEPRECATED_VERSION(5, 79, "use KCoreDirLister::listingDirCanceled(const QUrl &)")
+    void canceled(const QUrl &dirUrl); // clazy:exclude=overloaded-signal
+#endif
 
     /**
-     * Tell the view that the listing of the directory @p _url was canceled.
+     * Tell the view that the listing of the directory @p dirUrl was canceled.
      * There might be other running jobs left.
-     * @param _url the directory URL
+     *
+     * @param dirUrl the directory URL
+     *
+     * @since 5.79
      */
-    void canceled(const QUrl &_url);
+    void listingDirCanceled(const QUrl &dirUrl);
 
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 80)
     /**
      * Signal a redirection.
      * Only emitted if there's just one directory to list, i.e. most
      * probably openUrl() has been called without OpenUrlFlag::Keep.
-     * @param _url the new URL
+     *
+     * @param dirUrl the new URL
+     *
+     * @deprecated since 5.80, use redirection(const QUrl &, const QUrl &)
      */
-    void redirection(const QUrl &_url);
+    KIOCORE_DEPRECATED_VERSION(5, 80, "Use redirection(const QUrl &, const QUrl &)")
+    void redirection(const QUrl &_url); // clazy:exclude=overloaded-signal
+#endif
 
     /**
-     * Signal a redirection.
+     * Signals a redirection.
+     *
      * @param oldUrl the original URL
      * @param newUrl the new URL
      */
-    void redirection(const QUrl &oldUrl, const QUrl &newUrl);
+    void redirection(const QUrl &oldUrl, const QUrl &newUrl); // clazy:exclude=overloaded-signal
 
     /**
-     * Signal to clear all items.
-     * Make sure to connect to this signal to avoid doubled items.
+     * Signals to the view to remove all items (when e.g. going from dirA to dirB).
+     * Make sure to connect to this signal to avoid having duplicate items in the view.
      */
-    void clear();
+    void clear(); // clazy:exclude=overloaded-signal
+
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(5, 79)
+    /**
+     * Signals to the view to clear all items from directory @p dirUrl.
+     *
+     * This is only emitted if the lister is holding more than one directory.
+     *
+     * @param dirUrl the directory that the view should clear all items from
+     *
+     * @deprecated since 5.79, use clearDir(const QUrl &)
+     */
+    KIOCORE_DEPRECATED_VERSION(5, 79, "Use clearDir(const QUrl &)")
+    void clear(const QUrl &dirUrl); // clazy:exclude=overloaded-signal
+#endif
 
     /**
-     * Signal to empty the directory @p _url.
-     * It is only emitted if the lister is holding more than one directory.
-     * @param _url the directory that will be emptied
+     * Signals to the view to clear all items from directory @p dirUrl.
+     *
+     * This is only emitted if the lister is holding more than one directory.
+     *
+     * @param dirUrl the directory that the view should clear all items from
+     *
+     * @since 5.79
      */
-    void clear(const QUrl &_url);
+    void clearDir(const QUrl &dirUrl);
 
     /**
      * Signal new items.
@@ -494,7 +567,7 @@ Q_SIGNALS:
     void itemsAdded(const QUrl &directoryUrl, const KFileItemList &items);
 
     /**
-     * Send a list of items filtered-out by mime-type.
+     * Send a list of items filtered-out by MIME type.
      * @param items the list of filtered items
      */
     void itemsFilteredByMime(const KFileItemList &items);
@@ -508,14 +581,14 @@ Q_SIGNALS:
     void itemsDeleted(const KFileItemList &items);
 
     /**
-     * Signal an item to refresh (its mimetype/icon/name has changed).
+     * Signal an item to refresh (its MIME-type/icon/name has changed).
      * Note: KFileItem::refresh has already been called on those items.
      * @param items the items to refresh. This is a list of pairs, where
      * the first item in the pair is the OLD item, and the second item is the
      * NEW item. This allows to track which item has changed, especially after
      * a renaming.
      */
-    void refreshItems(const QList<QPair<KFileItem, KFileItem> > &items);
+    void refreshItems(const QList<QPair<KFileItem, KFileItem>> &items);
 
     /**
      * Emitted to display information about running jobs.
@@ -550,8 +623,10 @@ Q_SIGNALS:
     void speed(int bytes_per_second);
 
 protected:
-    /// @deprecated and unused, ignore this
+#if KIOCORE_ENABLE_DEPRECATED_SINCE(4, 3)
+    /// @deprecated Since 4.3, and unused, ignore this
     enum Changes { NONE = 0, NAME_FILTER = 1, MIME_FILTER = 2, DOT_FILES = 4, DIR_ONLY_MODE = 8 };
+#endif
 
     /**
      * Called for every new item before emitting newItems().
@@ -559,8 +634,8 @@ protected:
      * filtering.
      * The default implementation filters out ".." and everything not matching
      * the name filter(s)
-     * @return true if the item is "ok".
-     *         false if the item shall not be shown in a view, e.g.
+     * @return @c true if the item is "ok".
+     *         @c false if the item shall not be shown in a view, e.g.
      * files not matching a pattern *.cpp ( KFileItem::isHidden())
      * @see matchesFilter
      * @see setNameFilter
@@ -573,8 +648,8 @@ protected:
      * filtering.
      * The default implementation filters out ".." and everything not matching
      * the name filter(s)
-     * @return true if the item is "ok".
-     *         false if the item shall not be shown in a view, e.g.
+     * @return @c true if the item is "ok".
+     *         @c false if the item shall not be shown in a view, e.g.
      * files not matching a pattern *.cpp ( KFileItem::isHidden())
      * @see matchesMimeFilter
      * @see setMimeFilter
@@ -588,16 +663,18 @@ protected:
      * @param name the name to filter
      * @param filters a list of regular expressions for filtering
      */
+    // TODO KF6 remove
     virtual bool doNameFilter(const QString &name, const QList<QRegExp> &filters) const;
 
     /**
      * Called by the public matchesMimeFilter() to do the
      * actual filtering. Those methods may be reimplemented to customize
      * filtering.
-     * @param mime the mime type to filter
-     * @param filters the list of mime types to filter
+     * @param mimeType the MIME type to filter
+     * @param filters the list of MIME types to filter
      */
-    virtual bool doMimeFilter(const QString &mime, const QStringList &filters) const;
+    // TODO KF6 remove
+    virtual bool doMimeFilter(const QString &mimeType, const QStringList &filters) const;
 
     /**
      * Reimplement to customize error handling
@@ -615,18 +692,10 @@ protected:
     virtual void jobStarted(KIO::ListJob *);
 
 private:
-    class Private;
-    Private *const d;
-    friend class Private;
-
-    Q_PRIVATE_SLOT(d, void _k_slotInfoMessage(KJob *, const QString &))
-    Q_PRIVATE_SLOT(d, void _k_slotPercent(KJob *, unsigned long))
-    Q_PRIVATE_SLOT(d, void _k_slotTotalSize(KJob *, qulonglong))
-    Q_PRIVATE_SLOT(d, void _k_slotProcessedSize(KJob *, qulonglong))
-    Q_PRIVATE_SLOT(d, void _k_slotSpeed(KJob *, unsigned long))
+    friend class KCoreDirListerPrivate;
+    std::unique_ptr<KCoreDirListerPrivate> d;
 };
 
 Q_DECLARE_OPERATORS_FOR_FLAGS(KCoreDirLister::OpenUrlFlags)
 
 #endif
-
