@@ -1,23 +1,10 @@
-/* This file is part of the KDE project
-   Copyright (C) 2008 by Peter Penz <peter.penz@gmx.at>
-   Copyright (C) 2008 by George Goldberg <grundleborg@googlemail.com>
-   Copyright     2009 David Faure <faure@kde.org>
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2008 Peter Penz <peter.penz@gmx.at>
+    SPDX-FileCopyrightText: 2008 George Goldberg <grundleborg@googlemail.com>
+    SPDX-FileCopyrightText: 2009 David Faure <faure@kde.org>
 
-   This library is free software; you can redistribute it and/or modify
-   it under the terms of the GNU Library General Public License as published
-   by the Free Software Foundation; either version 2 of the License or
-   ( at your option ) version 3 or, at the discretion of KDE e.V.
-   ( which shall act as a proxy as in section 14 of the GPLv3 ), any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
 #include "kfileitemlistproperties.h"
@@ -31,14 +18,15 @@ class KFileItemListPropertiesPrivate : public QSharedData
 {
 public:
     KFileItemListPropertiesPrivate()
-        : m_isDirectory(false),
-          m_isFile(false),
-          m_supportsReading(false),
-          m_supportsDeleting(false),
-          m_supportsWriting(false),
-          m_supportsMoving(false),
-          m_isLocal(true)
-    { }
+        : m_isDirectory(false)
+        , m_isFile(false)
+        , m_supportsReading(false)
+        , m_supportsDeleting(false)
+        , m_supportsWriting(false)
+        , m_supportsMoving(false)
+        , m_isLocal(true)
+    {
+    }
     void setItems(const KFileItemList &items);
 
     void determineMimeTypeAndGroup() const;
@@ -90,10 +78,10 @@ void KFileItemListPropertiesPrivate::setItems(const KFileItemList &items)
         bool isLocal = false;
         const QUrl url = item.mostLocalUrl(&isLocal);
         m_isLocal = m_isLocal && isLocal;
-        m_supportsReading  = m_supportsReading  && KProtocolManager::supportsReading(url);
+        m_supportsReading = m_supportsReading && KProtocolManager::supportsReading(url);
         m_supportsDeleting = m_supportsDeleting && KProtocolManager::supportsDeleting(url);
-        m_supportsWriting  = m_supportsWriting  && KProtocolManager::supportsWriting(url) && item.isWritable();
-        m_supportsMoving   = m_supportsMoving   && KProtocolManager::supportsMoving(url);
+        m_supportsWriting = m_supportsWriting && KProtocolManager::supportsWriting(url) && item.isWritable();
+        m_supportsMoving = m_supportsMoving && KProtocolManager::supportsMoving(url);
 
         // For local files we can do better: check if we have write permission in parent directory
         // TODO: if we knew about the parent KFileItem, we could even do that for remote protocols too
@@ -126,7 +114,8 @@ void KFileItemListPropertiesPrivate::setItems(const KFileItemList &items)
 
 KFileItemListProperties::KFileItemListProperties(const KFileItemListProperties &other)
     : d(other.d)
-{ }
+{
+}
 
 KFileItemListProperties &KFileItemListProperties::operator=(const KFileItemListProperties &other)
 {
@@ -207,11 +196,11 @@ void KFileItemListPropertiesPrivate::determineMimeTypeAndGroup() const
     }
     for (const KFileItem &item : qAsConst(m_items)) {
         const QString itemMimeType = item.mimetype();
-        // Determine if common mimetype among all items
+        // Determine if common MIME type among all items
         if (m_mimeType != itemMimeType) {
             m_mimeType.clear();
             if (m_mimeGroup != itemMimeType.leftRef(itemMimeType.indexOf(QLatin1Char('/')))) {
-                m_mimeGroup.clear(); // mimetype groups are different as well!
+                m_mimeGroup.clear(); // MIME type groups are different as well!
             }
         }
     }
