@@ -9,6 +9,7 @@
 */
 
 #include "previewjob.h"
+#include "kio_widgets_debug.h"
 
 #if defined(Q_OS_UNIX) && !defined(Q_OS_ANDROID)
 #define WITH_SHM 1
@@ -27,27 +28,30 @@
 #include <QFile>
 #include <QImage>
 #include <QPixmap>
-#include <QTimer>
 #include <QRegularExpression>
-#include <QTemporaryFile>
 #include <QSaveFile>
+#include <QTemporaryFile>
+#include <QTimer>
 
 #include <QCryptographicHash>
 
-#include <kfileitem.h>
-#include <KServiceTypeTrader>
-#include <KService>
-#include <KSharedConfig>
 #include <KConfigGroup>
-#include <kprotocolinfo.h>
+#include <KMountPoint>
+#include <KService>
+#include <KServiceTypeTrader>
+#include <KSharedConfig>
 #include <QMimeDatabase>
 #include <QStandardPaths>
-#include <KMountPoint>
+#include <kprotocolinfo.h>
 
 #include <algorithm>
 
 #include "job_p.h"
 
+namespace  {
+    static int s_defaultDevicePixelRatio = 1;
+}
+
 namespace KIO
 {
 struct PreviewItem;
@@ -59,35 +63,35 @@ struct KIO::PreviewItem {
     KService::Ptr plugin;
 };
 
-class KIO::PreviewJobPrivate: public KIO::JobPrivate
+class KIO::PreviewJobPrivate : public KIO::JobPrivate
 {
 public:
     PreviewJobPrivate(const KFileItemList &items, const QSize &size)
-        : initialItems(items),
-          width(size.width()),
-          height(size.height()),
-          cacheWidth(width),
-          cacheHeight(height),
-          bScale(true),
-          bSave(true),
-          ignoreMaximumSize(false),
-          sequenceIndex(0),
-          succeeded(false),
-          maximumLocalSize(0),
-          maximumRemoteSize(0),
-          iconSize(0),
-          iconAlpha(70),
-          shmid(-1),
-          shmaddr(nullptr)
+        : initialItems(items)
+        , width(size.width())
+        , height(size.height())
+        , cacheSize(-1)
+        , bScale(true)
+        , bSave(true)
+        , ignoreMaximumSize(false)
+        , sequenceIndex(0)
+        , succeeded(false)
+        , maximumLocalSize(0)
+        , maximumRemoteSize(0)
+        , iconSize(0)
+        , iconAlpha(70)
+        , shmid(-1)
+        , shmaddr(nullptr)
     {
         // http://specifications.freedesktop.org/thumbnail-spec/thumbnail-spec-latest.html#DIRECTORY
         thumbRoot = QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation) + QLatin1String("/thumbnails/");
     }
 
-    enum { STATE_STATORIG, // if the thumbnail exists
-           STATE_GETORIG, // if we create it
-           STATE_CREATETHUMB // thumbnail:/ slave
-         } state;
+    enum {
+        STATE_STATORIG, // if the thumbnail exists
+        STATE_GETORIG, // if we create it
+        STATE_CREATETHUMB, // thumbnail:/ slave
+    } state;
 
     KFileItemList initialItems;
     QStringList enabledPlugins;
@@ -111,8 +115,7 @@ public:
     int width;
     int height;
     // Unscaled size of thumbnail (128 or 256 if cache is enabled)
-    int cacheWidth;
-    int cacheHeight;
+    int cacheSize;
     // Whether the thumbnail should be scaled
     bool bScale;
     // Whether we should save the thumbnail
@@ -126,7 +129,7 @@ public:
     KIO::filesize_t maximumRemoteSize;
     // the size for the icon overlay
     int iconSize;
-    // the transparency of the blended mimetype icon
+    // the transparency of the blended MIME type icon
     int iconAlpha;
     // Shared memory segment Id. The segment is allocated to a size
     // of extent x extent x 4 (32 bit image) on first need.
@@ -137,6 +140,9 @@ public:
     QString thumbRoot;
     // List of encrypted mount points for checking if we should save thumbnail
     KMountPoint::List encryptedMountsList;
+    // Metadata returned from the KIO thumbnail slave
+    QMap<QString, QString> thumbnailSlaveMetaData;
+    int devicePixelRatio = s_defaultDevicePixelRatio;
 
     void getOrCreateThumbnail();
     bool statResultThumbnail();
@@ -151,10 +157,13 @@ public:
     Q_DECLARE_PUBLIC(PreviewJob)
 };
 
+void PreviewJob::setDefaultDevicePixelRatio(int defaultDevicePixelRatio)
+{
+    s_defaultDevicePixelRatio = defaultDevicePixelRatio;
+}
+
 #if KIOWIDGETS_BUILD_DEPRECATED_SINCE(4, 7)
-PreviewJob::PreviewJob(const KFileItemList &items, int width, int height,
-                       int iconSize, int iconAlpha, bool scale, bool save,
-                       const QStringList *enabledPlugins)
+PreviewJob::PreviewJob(const KFileItemList &items, int width, int height, int iconSize, int iconAlpha, bool scale, bool save, const QStringList *enabledPlugins)
     : KIO::Job(*new PreviewJobPrivate(items, QSize(width, height ? height : width)))
 {
     Q_D(PreviewJob);
@@ -169,10 +178,8 @@ PreviewJob::PreviewJob(const KFileItemList &items, int width, int height,
 }
 #endif
 
-PreviewJob::PreviewJob(const KFileItemList &items,
-                       const QSize &size,
-                       const QStringList *enabledPlugins) :
-    KIO::Job(*new PreviewJobPrivate(items, size))
+PreviewJob::PreviewJob(const KFileItemList &items, const QSize &size, const QStringList *enabledPlugins)
+    : KIO::Job(*new PreviewJobPrivate(items, size))
 {
     Q_D(PreviewJob);
 
@@ -180,10 +187,9 @@ PreviewJob::PreviewJob(const KFileItemList &items,
         d->enabledPlugins = *enabledPlugins;
     } else {
         const KConfigGroup globalConfig(KSharedConfig::openConfig(), "PreviewSettings");
-        d->enabledPlugins = globalConfig.readEntry("Plugins", QStringList {
-                                                                  QStringLiteral("directorythumbnail"),
-                                                                  QStringLiteral("imagethumbnail"),
-                                                                  QStringLiteral("jpegthumbnail")});
+        d->enabledPlugins =
+            globalConfig.readEntry("Plugins",
+                                   QStringList{QStringLiteral("directorythumbnail"), QStringLiteral("imagethumbnail"), QStringLiteral("jpegthumbnail")});
     }
 
     // Return to event loop first, determineNextFile() might delete this;
@@ -258,10 +264,10 @@ PreviewJob::ScaleType PreviewJob::scaleType() const
 void PreviewJobPrivate::startPreview()
 {
     Q_Q(PreviewJob);
-    // Load the list of plugins to determine which mimetypes are supported
+    // Load the list of plugins to determine which MIME types are supported
     const KService::List plugins = KServiceTypeTrader::self()->query(QStringLiteral("ThumbCreator"));
     QMap<QString, KService::Ptr> mimeMap;
-    QHash<QString, QHash<QString, KService::Ptr> > protocolMap;
+    QHash<QString, QHash<QString, KService::Ptr>> protocolMap;
 
     for (KService::List::ConstIterator it = plugins.constBegin(); it != plugins.constEnd(); ++it) {
         QStringList protocols = (*it)->property(QStringLiteral("X-KDE-Protocols")).toStringList();
@@ -272,7 +278,7 @@ void PreviewJobPrivate::startPreview()
         for (const QString &protocol : qAsConst(protocols)) {
             // We cannot use mimeTypes() here, it doesn't support groups such as: text/*
             const QStringList mtypes = (*it)->serviceTypes();
-            // Add supported mimetype for this protocol
+            // Add supported MIME type for this protocol
             QStringList &_ms = m_remoteProtocolPlugins[protocol];
             for (const QString &_m : mtypes) {
                 if (_m != QLatin1String("ThumbCreator")) {
@@ -293,16 +299,12 @@ void PreviewJobPrivate::startPreview()
         }
     }
 
-    //Prepare encryptedMountsList which will be used in ::slotThumbData
+    // Prepare encryptedMountsList which will be used in ::slotThumbData
     const auto mountsList = KMountPoint::currentMountPoints();
     const auto thumbRootMount = mountsList.findByPath(thumbRoot);
-    std::copy_if(mountsList.begin(), mountsList.end(),
-                 std::back_inserter(encryptedMountsList),
-                 [&thumbRootMount] (KMountPoint::Ptr mount) {
-                     return (thumbRootMount != mount) &&
-                            (mount->mountType() == QLatin1String("fuse.cryfs") ||
-                             mount->mountType() == QLatin1String("fuse.encfs"));
-                 });
+    std::copy_if(mountsList.begin(), mountsList.end(), std::back_inserter(encryptedMountsList), [&thumbRootMount](KMountPoint::Ptr mount) {
+        return (thumbRootMount != mount) && (mount->mountType() == QLatin1String("fuse.cryfs") || mount->mountType() == QLatin1String("fuse.encfs"));
+    });
 
     // Look for images and store the items in our todo list :)
     bool bNeedCache = false;
@@ -316,7 +318,7 @@ void PreviewJobPrivate::startPreview()
         KService::Ptr plugin(nullptr);
 
         // look for protocol-specific thumbnail plugins first
-        QHash<QString, QHash<QString, KService::Ptr> >::const_iterator it = protocolMap.constFind(item.item.url().scheme());
+        QHash<QString, QHash<QString, KService::Ptr>>::const_iterator it = protocolMap.constFind(item.item.url().scheme());
         if (it != protocolMap.constEnd()) {
             plugin = it.value().value(mimeType);
         }
@@ -330,7 +332,7 @@ void PreviewJobPrivate::startPreview()
 
                 if (pluginIt == mimeMap.constEnd()) {
                     QMimeDatabase db;
-                    // check mime type inheritance, resolve aliases
+                    // check MIME type inheritance, resolve aliases
                     const QMimeType mimeInfo = db.mimeTypeForName(mimeType);
                     if (mimeInfo.isValid()) {
                         const QStringList parentMimeTypes = mimeInfo.allAncestors();
@@ -354,13 +356,12 @@ void PreviewJobPrivate::startPreview()
             items.push_back(item);
             if (!bNeedCache && bSave && plugin->property(QStringLiteral("CacheThumbnail")).toBool()) {
                 const QUrl url = (*kit).url();
-                if (!url.isLocalFile() ||
-                        !url.adjusted(QUrl::RemoveFilename).toLocalFile().startsWith(thumbRoot)) {
+                if (!url.isLocalFile() || !url.adjusted(QUrl::RemoveFilename).toLocalFile().startsWith(thumbRoot)) {
                     bNeedCache = true;
                 }
             }
         } else {
-            emit q->failed(*kit);
+            Q_EMIT q->failed(*kit);
         }
     }
 
@@ -369,12 +370,39 @@ void PreviewJobPrivate::startPreview()
     maximumRemoteSize = cg.readEntry("MaximumRemoteSize", 0);
 
     if (bNeedCache) {
+
         if (width <= 128 && height <= 128) {
-            cacheWidth = cacheHeight = 128;
+            cacheSize = 128;
+        } else if (width <= 256 && height <= 256) {
+            cacheSize = 256;
         } else {
-            cacheWidth = cacheHeight = 256;
+            cacheSize = 512;
         }
-        thumbPath = thumbRoot + QLatin1String(cacheWidth == 128 ? "normal/" : "large/");
+
+        struct CachePool {
+            QString path;
+            int minSize;
+        };
+
+        const static auto pools = {
+            CachePool{QStringLiteral("/normal/"), 128},
+            CachePool{QStringLiteral("/large/"), 256},
+            CachePool{QStringLiteral("/x-large/"), 512},
+            CachePool{QStringLiteral("/xx-large/"), 1024},
+        };
+
+        QString thumbDir;
+        int wants = devicePixelRatio * cacheSize;
+        for (const auto &p : pools) {
+            if (p.minSize < wants) {
+                continue;
+            } else {
+                thumbDir = p.path;
+                break;
+            }
+        }
+        thumbPath = thumbRoot + thumbDir;
+
         if (!QDir(thumbPath).exists()) {
             if (QDir().mkpath(thumbPath)) { // Qt5 TODO: mkpath(dirPath, permissions)
                 QFile f(thumbPath);
@@ -420,6 +448,21 @@ int KIO::PreviewJob::sequenceIndex() const
     return d_func()->sequenceIndex;
 }
 
+float KIO::PreviewJob::sequenceIndexWraparoundPoint() const
+{
+    return d_func()->thumbnailSlaveMetaData.value(QStringLiteral("sequenceIndexWraparoundPoint"), QStringLiteral("-1.0")).toFloat();
+}
+
+bool KIO::PreviewJob::handlesSequences() const
+{
+    return d_func()->thumbnailSlaveMetaData.value(QStringLiteral("handlesSequences")) == QStringLiteral("1");
+}
+
+void KIO::PreviewJob::setDevicePixelRatio(int dpr)
+{
+    d_func()->devicePixelRatio = dpr;
+}
+
 void PreviewJob::setIgnoreMaximumSize(bool ignoreSize)
 {
     d_func()->ignoreMaximumSize = ignoreSize;
@@ -439,7 +482,7 @@ void PreviewJobPrivate::determineNextFile()
     Q_Q(PreviewJob);
     if (!currentItem.item.isNull()) {
         if (!succeeded) {
-            emit q->failed(currentItem.item);
+            Q_EMIT q->failed(currentItem.item);
         }
     }
     // No more items ?
@@ -464,7 +507,7 @@ void PreviewJob::slotResult(KJob *job)
     Q_D(PreviewJob);
 
     removeSubjob(job);
-    Q_ASSERT(!hasSubjobs());    // We should have only one job at a time ...
+    Q_ASSERT(!hasSubjobs()); // We should have only one job at a time ...
     switch (d->state) {
     case PreviewJobPrivate::STATE_STATORIG: {
         if (job->error()) { // that's no good news...
@@ -480,8 +523,8 @@ void PreviewJob::slotResult(KJob *job)
         const QUrl itemUrl = d->currentItem.item.mostLocalUrl();
 
         if (itemUrl.isLocalFile() || KProtocolInfo::protocolClass(itemUrl.scheme()) == QLatin1String(":local")) {
-            skipCurrentItem = !d->ignoreMaximumSize && size > d->maximumLocalSize
-                              && !d->currentItem.plugin->property(QStringLiteral("IgnoreMaximumSize")).toBool();
+            skipCurrentItem =
+                !d->ignoreMaximumSize && size > d->maximumLocalSize && !d->currentItem.plugin->property(QStringLiteral("IgnoreMaximumSize")).toBool();
         } else {
             // For remote items the "IgnoreMaximumSize" plugin property is not respected
             skipCurrentItem = !d->ignoreMaximumSize && size > d->maximumRemoteSize;
@@ -489,7 +532,7 @@ void PreviewJob::slotResult(KJob *job)
             // Remote directories are not supported, don't try to do a file_copy on them
             if (!skipCurrentItem) {
                 // TODO update item.mimeType from the UDS entry, in case it wasn't set initially
-                // But we don't use the mimetype anymore, we just use isDir().
+                // But we don't use the MIME type anymore, we just use isDir().
                 if (d->currentItem.item.isDir()) {
                     skipCurrentItem = true;
                 }
@@ -501,7 +544,7 @@ void PreviewJob::slotResult(KJob *job)
         }
 
         bool pluginHandlesSequences = d->currentItem.plugin->property(QStringLiteral("HandleSequences"), QVariant::Bool).toBool();
-        if (!d->currentItem.plugin->property(QStringLiteral("CacheThumbnail")).toBool()  || (d->sequenceIndex && pluginHandlesSequences)) {
+        if (!d->currentItem.plugin->property(QStringLiteral("CacheThumbnail")).toBool() || (d->sequenceIndex && pluginHandlesSequences)) {
             // This preview will not be cached, no need to look for a saved thumbnail
             // Just create it, and be done
             d->getOrCreateThumbnail();
@@ -539,29 +582,51 @@ bool PreviewJobPrivate::statResultThumbnail()
         return false;
     }
 
-    const QUrl url = currentItem.item.mostLocalUrl();
-    // Don't include the password if any
-    origName = url.toEncoded(QUrl::RemovePassword);
+    bool isLocal;
+    const QUrl url = currentItem.item.mostLocalUrl(&isLocal);
+    if (isLocal) {
+        const QFileInfo localFile(url.toLocalFile());
+        const QString canonicalPath = localFile.canonicalFilePath();
+        origName = QUrl::fromLocalFile(canonicalPath).toEncoded(QUrl::RemovePassword | QUrl::FullyEncoded);
+        if (origName.isEmpty()) {
+            qCWarning(KIO_WIDGETS) << "Failed to convert" << url << "to canonical path";
+            return false;
+        }
+    } else {
+        // Don't include the password if any
+        origName = url.toEncoded(QUrl::RemovePassword);
+    }
 
     QCryptographicHash md5(QCryptographicHash::Md5);
     md5.addData(origName);
     thumbName = QString::fromLatin1(md5.result().toHex()) + QLatin1String(".png");
 
     QImage thumb;
-    if (!thumb.load(thumbPath + thumbName)) {
+    QFile thumbFile(thumbPath + thumbName);
+    if (!thumbFile.open(QIODevice::ReadOnly) || !thumb.load(&thumbFile, "png")) {
         return false;
     }
 
-    if (thumb.text(QStringLiteral("Thumb::URI")) != QString::fromUtf8(origName) ||
-            thumb.text(QStringLiteral("Thumb::MTime")).toLongLong() != tOrig.toSecsSinceEpoch()) {
+    if (thumb.text(QStringLiteral("Thumb::URI")) != QString::fromUtf8(origName)
+        || thumb.text(QStringLiteral("Thumb::MTime")).toLongLong() != tOrig.toSecsSinceEpoch()) {
         return false;
     }
 
+    const QString origSize = thumb.text(QStringLiteral("Thumb::Size"));
+    if (!origSize.isEmpty() && origSize.toULongLong() != currentItem.item.size()) {
+        // Thumb::Size is not required, but if it is set it should match
+        return false;
+    }
+
+    if (thumb.width() == width * devicePixelRatio || thumb.height() == height * devicePixelRatio) {
+        thumb.setDevicePixelRatio(devicePixelRatio);
+    }
+
     QString thumbnailerVersion = currentItem.plugin->property(QStringLiteral("ThumbnailerVersion"), QVariant::String).toString();
 
     if (!thumbnailerVersion.isEmpty() && thumb.text(QStringLiteral("Software")).startsWith(QLatin1String("KDE Thumbnail Generator"))) {
-        //Check if the version matches
-        //The software string should read "KDE Thumbnail Generator pluginName (vX)"
+        // Check if the version matches
+        // The software string should read "KDE Thumbnail Generator pluginName (vX)"
         QString softwareString = thumb.text(QStringLiteral("Software")).remove(QStringLiteral("KDE Thumbnail Generator")).trimmed();
         if (softwareString.isEmpty()) {
             // The thumbnail has been created with an older version, recreating
@@ -601,7 +666,7 @@ void PreviewJobPrivate::getOrCreateThumbnail()
         // heuristics for remote URL support
         bool supportsProtocol = false;
         if (m_remoteProtocolPlugins.value(fileUrl.scheme()).contains(item.mimetype())) {
-            // There's a plugin supporting this protocol and mimetype
+            // There's a plugin supporting this protocol and MIME type
             supportsProtocol = true;
         } else if (m_remoteProtocolPlugins.value(QStringLiteral("KIO")).contains(item.mimetype())) {
             // Assume KIO understands any URL, ThumbCreator slaves who have
@@ -642,15 +707,19 @@ void PreviewJobPrivate::createThumbnail(const QString &pixPath)
     thumbURL.setPath(pixPath);
     KIO::TransferJob *job = KIO::get(thumbURL, NoReload, HideProgressInfo);
     q->addSubjob(job);
-    q->connect(job, SIGNAL(data(KIO::Job*,QByteArray)), SLOT(slotThumbData(KIO::Job*,QByteArray)));
+    q->connect(job, &KIO::TransferJob::data, q, [this](KIO::Job *job, const QByteArray &data) {
+        slotThumbData(job, data);
+    });
+
     bool save = bSave && currentItem.plugin->property(QStringLiteral("CacheThumbnail")).toBool() && !sequenceIndex;
     job->addMetaData(QStringLiteral("mimeType"), currentItem.item.mimetype());
-    job->addMetaData(QStringLiteral("width"), QString().setNum(save ? cacheWidth : width));
-    job->addMetaData(QStringLiteral("height"), QString().setNum(save ? cacheHeight : height));
+    job->addMetaData(QStringLiteral("width"), QString().setNum(save ? cacheSize : width));
+    job->addMetaData(QStringLiteral("height"), QString().setNum(save ? cacheSize : height));
     job->addMetaData(QStringLiteral("iconSize"), QString().setNum(save ? 64 : iconSize));
     job->addMetaData(QStringLiteral("iconAlpha"), QString().setNum(iconAlpha));
     job->addMetaData(QStringLiteral("plugin"), currentItem.plugin->library());
     job->addMetaData(QStringLiteral("enabledPlugins"), enabledPlugins.join(QLatin1Char(',')));
+    job->addMetaData(QStringLiteral("devicePixelRatio"), QString::number(devicePixelRatio));
     if (sequenceIndex) {
         job->addMetaData(QStringLiteral("sequence-index"), QString().setNum(sequenceIndex));
     }
@@ -661,10 +730,11 @@ void PreviewJobPrivate::createThumbnail(const QString &pixPath)
             shmdt((char *)shmaddr);
             shmctl(shmid, IPC_RMID, nullptr);
         }
-        shmid = shmget(IPC_PRIVATE, cacheWidth * cacheHeight * 4, IPC_CREAT | 0600);
+        auto size = std::max(cacheSize * cacheSize, width * height);
+        shmid = shmget(IPC_PRIVATE, size * 4 * devicePixelRatio * devicePixelRatio, IPC_CREAT | 0600);
         if (shmid != -1) {
             shmaddr = (uchar *)(shmat(shmid, nullptr, SHM_RDONLY));
-            if (shmaddr == (uchar *) - 1) {
+            if (shmaddr == (uchar *)-1) {
                 shmctl(shmid, IPC_RMID, nullptr);
                 shmaddr = nullptr;
                 shmid = -1;
@@ -679,14 +749,19 @@ void PreviewJobPrivate::createThumbnail(const QString &pixPath)
 #endif
 }
 
-void PreviewJobPrivate::slotThumbData(KIO::Job *, const QByteArray &data)
+void PreviewJobPrivate::slotThumbData(KIO::Job *job, const QByteArray &data)
 {
+    thumbnailSlaveMetaData = job->metaData();
     const bool isEncrypted = encryptedMountsList.findByPath(currentItem.item.url().toLocalFile());
-    bool save = bSave &&
-                !sequenceIndex && !isEncrypted &&
-                currentItem.plugin->property(QStringLiteral("CacheThumbnail")).toBool() &&
-                (!currentItem.item.url().isLocalFile() ||
-                 !currentItem.item.url().adjusted(QUrl::RemoveFilename).toLocalFile().startsWith(thumbRoot));
+    /* clang-format off */
+    const bool save = bSave
+                      && !sequenceIndex
+                      && !isEncrypted
+                      && currentItem.plugin->property(QStringLiteral("CacheThumbnail")).toBool()
+                      && (!currentItem.item.url().isLocalFile()
+                          || !currentItem.item.url().adjusted(QUrl::RemoveFilename).toLocalFile().startsWith(thumbRoot));
+    /* clang-format on */
+
     QImage thumb;
 #if WITH_SHM
     if (shmaddr) {
@@ -694,9 +769,17 @@ void PreviewJobPrivate::slotThumbData(KIO::Job *, const QByteArray &data)
         QDataStream str(data);
         int width, height;
         quint8 iFormat;
+        int imgDevicePixelRatio = 1;
+        // TODO KF6: add a version number as first parameter
         str >> width >> height >> iFormat;
+        if (iFormat & 0x80) {
+            // HACK to deduce if imgDevicePixelRatio is present
+            iFormat &= 0x7f;
+            str >> imgDevicePixelRatio;
+        }
         QImage::Format format = static_cast<QImage::Format>(iFormat);
         thumb = QImage(shmaddr, width, height, format).copy();
+        thumb.setDevicePixelRatio(imgDevicePixelRatio);
     } else
 #endif
         thumb.loadFromData(data);
@@ -732,12 +815,13 @@ void PreviewJobPrivate::emitPreview(const QImage &thumb)
 {
     Q_Q(PreviewJob);
     QPixmap pix;
-    if (thumb.width() > width || thumb.height() > height) {
-        pix = QPixmap::fromImage(thumb.scaled(QSize(width, height), Qt::KeepAspectRatio, Qt::SmoothTransformation));
+    if (thumb.width() > width * thumb.devicePixelRatio() || thumb.height() > height * thumb.devicePixelRatio()) {
+        pix = QPixmap::fromImage(thumb.scaled(QSize(width * thumb.devicePixelRatio(), height * thumb.devicePixelRatio()), Qt::KeepAspectRatio, Qt::SmoothTransformation));
     } else {
         pix = QPixmap::fromImage(thumb);
     }
-    emit q->gotPreview(currentItem.item, pix);
+    pix.setDevicePixelRatio(thumb.devicePixelRatio());
+    Q_EMIT q->gotPreview(currentItem.item, pix);
 }
 
 QStringList PreviewJob::availablePlugins()
@@ -755,8 +839,7 @@ QStringList PreviewJob::availablePlugins()
 
 QStringList PreviewJob::defaultPlugins()
 {
-    const QStringList blacklist = QStringList()
-                            << QStringLiteral("textthumbnail");
+    const QStringList blacklist = QStringList() << QStringLiteral("textthumbnail");
 
     QStringList defaultPlugins = availablePlugins();
     for (const QString &plugin : blacklist) {
@@ -777,28 +860,24 @@ QStringList PreviewJob::supportedMimeTypes()
 }
 
 #if KIOWIDGETS_BUILD_DEPRECATED_SINCE(4, 7)
-PreviewJob *KIO::filePreview(const KFileItemList &items, int width, int height,
-                             int iconSize, int iconAlpha, bool scale, bool save,
-                             const QStringList *enabledPlugins)
+PreviewJob *
+KIO::filePreview(const KFileItemList &items, int width, int height, int iconSize, int iconAlpha, bool scale, bool save, const QStringList *enabledPlugins)
 {
-    return new PreviewJob(items, width, height, iconSize, iconAlpha,
-                          scale, save, enabledPlugins);
+    return new PreviewJob(items, width, height, iconSize, iconAlpha, scale, save, enabledPlugins);
 }
 #endif
 
 #if KIOWIDGETS_BUILD_DEPRECATED_SINCE(4, 7)
-PreviewJob *KIO::filePreview(const QList<QUrl> &items, int width, int height,
-                             int iconSize, int iconAlpha, bool scale, bool save,
-                             const QStringList *enabledPlugins)
+PreviewJob *
+KIO::filePreview(const QList<QUrl> &items, int width, int height, int iconSize, int iconAlpha, bool scale, bool save, const QStringList *enabledPlugins)
 {
     KFileItemList fileItems;
     fileItems.reserve(items.size());
     for (const QUrl &url : items) {
-        Q_ASSERT(url.isValid());   // please call us with valid urls only
+        Q_ASSERT(url.isValid()); // please call us with valid urls only
         fileItems.append(KFileItem(url));
     }
-    return new PreviewJob(fileItems, width, height, iconSize, iconAlpha,
-                          scale, save, enabledPlugins);
+    return new PreviewJob(fileItems, width, height, iconSize, iconAlpha, scale, save, enabledPlugins);
 }
 #endif
 
